@@ -4,9 +4,9 @@ __author__ = "Christian Heider Nielsen"
 __doc__ = r"""
 """
 
-import pathlib
+from pathlib import Path
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
 from .truncation import *
@@ -14,4 +14,3 @@ from .signal_statistics import *
 from .signal_mixing import *
 from .signal_projection import *
 from .padding import *
-from .subsampling import *
