@@ -15,3 +15,6 @@ with open(Path(__file__).parent / "README.md", "r") as this_init_file:
 
 from .tensorboard import *
 from .torch_module_writer import *
+from .mixins import *
+
+# from .visdom import *
