@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+import numpy
+import visdom
+
 from draugr.writers.writer import Writer
 
 __author__ = "Christian Heider Nielsen"
@@ -22,11 +25,17 @@ if not START_VISDOM_SERVER:
 class VisdomWriter(Writer):
     """ """
 
+    def __init__(self):
+        super().__init__()
+
     def _scalar(self, tag: str, value: float, step: int):
-        pass
+        self.server.line(
+            Y=numpy.array([value]), X=numpy.array([step]), win=tag, update="append"
+        )
 
     def _close(self, exc_type=None, exc_val=None, exc_tb=None):
-        pass
+        # self.server.close() # close a window by id
+        del self.server
 
     def _open(self):
-        pass
+        self.server = visdom.Visdom(server=VISDOM_SERVER, port=8097)
