@@ -20,14 +20,11 @@ class FigureWriterMixin(ABC):
     def figure(self, tag: str, figure: Figure, step: int, **kwargs) -> None:
         """
 
+            :param figure:
         :param tag:
         :type tag:
-        :param data:
-        :type data:
         :param step:
         :type step:
-        :param dataformats:
-        :type dataformats:
         :param kwargs:
         :type kwargs:"""
         raise NotImplementedError
