@@ -7,6 +7,11 @@ __doc__ = r"""
            Created on 9/14/19
            """
 
+from pathlib import Path
+
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
+    __doc__ += this_init_file.read()
+
 from .terminal_plot import *
 from .terminal_plot_writer import *
 from .console_writer import *
